package com.huaching.parking.local.parking_local_general.controller.local;

import com.alibaba.fastjson.JSON;
import com.huaching.parking.local.parking_local_general.domain.ResponseResult;
import com.huaching.parking.local.parking_local_general.domain.local.dto.response.ThsChannelMeeageDTO;
import com.huaching.parking.local.parking_local_general.enums.local.ReasonCodeEnums;
import com.huaching.parking.local.parking_local_general.intercept.local.GeneralPrintLogAOP;
import com.huaching.parking.local.parking_local_general.service.local.base.ChannelMessageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @program: parking_local_general
 * @description: 停车场信息相关接口（下行）
 * @author: lidongsheng
 * @createData: 2020-04-17 11:41
 * @updateAuthor: lidongsheng
 * @updateData: 2020-04-17 11:41
 * @updateContent: 请求controller
 * @Version: 1.0.0
 * <p>
 * ************************************************
 * Copyright @ 李东升 2020. All rights reserved
 * ************************************************
 */
@Api(value = "云平台 停车场信息相关下行接口controller")
@RestController
@RequestMapping(value = "/ths/request/parkMessage")
public class ParkMessageController {

    private static final Logger logger = LoggerFactory.getLogger(ParkMessageController.class);

    @Autowired
    private ChannelMessageService channelMessageService;

    /**
     * 根据车场编号和通道编号获得通道详细信息
     *
     * @return
     */
    @ApiOperation(value = "根据车场编号和通道编号获得通道详细信接口")
    @PostMapping("/getChannelMessage")
    @GeneralPrintLogAOP(value = "根据车场编号和通道编号获得通道详细信接口")
    public ResponseResult getChannelMessage(@RequestBody String parkCode, @RequestBody String channelCode) {
        logger.info("根据车场编号和通道编号获得通道详细信息 parkCode -> {} , channelCode -> {}", parkCode, channelCode);
        ThsChannelMeeageDTO thsChannelMeeageDTO = ThsChannelMeeageDTO.poConvertToDto(channelMessageService.getChannelMessage(parkCode, channelCode));
        if (thsChannelMeeageDTO != null) {
            return ResponseResult.Builder.init().setData(JSON.toJSONString(thsChannelMeeageDTO)).build();
        } else {
            logger.error("根据车场编号和通道编号未查询到通道详细信息 parkCode -> {} , channelCode -> {}", parkCode, channelCode);
            return ResponseResult.Builder.init().setFailMessage(ReasonCodeEnums.EMPTY_RESULT, "无此通道信息").build();
        }
    }

    public static int reverse(int x) {

        int res = 0;
        while (x != 0) {
            int temp = x % 10;
            if (res > 214748364 || res < -214748364) {
                return 0;
            }
            res = res * 10 + temp;
            x = x / 10;
        }
        return res;
    }


    //四个方向，顺时针
    int[][] direction = {
            {-1, 0},
            {0, 1},
            {1, 0},
            {0, -1}
    };
    int m, n;
    boolean[][] visit;

    public int dfs(int[][] mat, int x, int y) {
        int maxLen = 1;
        visit[x][y] = true;
        for (int i = 0; i < 4; i++) {
            int newX = x + direction[i][0];
            int newY = y + direction[i][1];
            if (inArr(newX, newY) && !visit[newX][newY] && mat[newX][newY] > mat[x][y]) {
                int temp = dfs(mat, newX, newY) + 1;
                maxLen = Math.max(temp, maxLen);
            }
        }
        visit[x][y] = false;
        return maxLen;
    }

    public boolean inArr(int x, int y) {
        if (x >= 0 && y >= 0 && x < m && y < n) {
            return true;
        }
        return false;
    }

    public int solo(int[][] mat) {
        m = mat.length;
        if (m == 0) return 0;
        n = mat[0].length;
        visit = new boolean[m][n];
        int ans = 0;
        for (int i = 0; i < m; i++) {
            for (int j = 0; j < n; j++) {
                int len = dfs(mat, i, j);
                ans = Math.max(ans, len);
            }
        }
        return ans;
    }

    public static void main(String[] args) {
        ParkMessageController controller = new ParkMessageController();
        int[][] nums = new int[][]{
                {3, 4, 5},
                {11, 5, 6},
                {12, 8, 7}
        };
        System.out.println(controller.solo(nums));
    }
}
